<?php

/**
 * This file is part of the MADIS - RGPD Management application.
 *
 * @copyright Copyright (c) 2018-2019 Soluris - Solutions Numériques Territoriales Innovantes
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

declare(strict_types=1);

namespace App\Domain\Maturity\Form\Type;

use App\Domain\Maturity\Model;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\CollectionType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class ReferentielType extends AbstractType
{
    /**
     * Build type form.
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('name', TextType::class, [
                'label'    => 'maturity.referentiel.label.referentiel',
                'required' => true,
                'attr'     => [
                    'maxlength' => 1000,
                ],
                'purify_html' => true,
            ])
            ->add('description', TextareaType::class, [
                'label'    => 'maturity.referentiel.label.description',
                'required' => false,
                'attr'     => [
                    'rows' => 3,
                ],
                'purify_html' => true,
            ])
            ->add('report', CheckboxType::class, [
                'label'    => 'maturity.referentiel.label.report',
                'required' => false,
            ])
            ->add('domains', CollectionType::class, [
                'entry_type'     => DomainType::class,
                'allow_add'      => true,
                'allow_delete'   => true,
                'by_reference'   => false,
                'prototype_name' => '__section_name__',
            ])
        ;
    }

    /**
     * Provide type options.
     */
    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver
            ->setDefaults([
                'data_class'        => Model\Referentiel::class,
                'validation_groups' => [
                    'default',
                    'referentiel',
                ],
            ])
        ;
    }
}
