<?php

/**
 * This file is part of the MADIS - RGPD Management application.
 *
 * @copyright Copyright (c) 2018-2019 Soluris - Solutions Numériques Territoriales Innovantes
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

declare(strict_types=1);

namespace App\Domain\Maturity\Form\Type;

use App\Domain\Maturity\Model;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CollectionType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class SurveyType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        /** @var Model\Referentiel $ref */
        $ref = $options['data']->getReferentiel();

        $builder
            ->add('context', TextareaType::class, [
                'label'    => 'maturity.survey.label.context',
                'required' => false,
                'attr'     => [
                    'rows' => 5,
                ],
                'purify_html' => true,
            ])
            ->add('referentiel', EntityType::class, [
                'class'      => Model\Referentiel::class,
                'empty_data' => $ref,
            ])
            ->add('questions', CollectionType::class, [
                'entry_type' => SurveyAnswerType::class,
                'mapped'     => false,
            ])
            ->add('openQuestions', CollectionType::class, [
                'entry_type' => OpenAnswerType::class,
                'mapped'     => false,
            ])
        ;
    }

    /**
     * Provide type options.
     */
    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver
            ->setDefaults([
                'data_class'        => Model\Survey::class,
                'validation_groups' => [
                    'default',
                    'survey',
                ],
            ])
        ;
    }
}
