<?php

/**
 * This file is part of the MADIS - RGPD Management application.
 *
 * @copyright Copyright (c) 2018-2019 Soluris - Solutions Numériques Territoriales Innovantes
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

declare(strict_types=1);

namespace App\Domain\Registry\Dictionary;

use App\Application\Dictionary\SimpleDictionary;

class ToolTypeDictionary extends SimpleDictionary
{
    public const string SOFTWARE = 'software';
    public const string SUPPORT  = 'support';
    public const string PLACE    = 'place';
    public const string NETWORK  = 'network';

    public function __construct()
    {
        parent::__construct('registry_tool_type', self::getTypes());
    }

    /**
     * Get an array of Origins.
     *
     * @return array
     */
    public static function getTypes()
    {
        return [
            self::SOFTWARE => 'Logiciel',
            self::SUPPORT  => 'Support/Stockage',
            self::PLACE    => 'Bâtiment/Lieu',
            self::NETWORK  => 'Réseau/Connectivité',
        ];
    }

    /**
     * Get keys of the Origins array.
     *
     * @return array
     */
    public static function getTypesKeys()
    {
        return \array_keys(self::getTypes());
    }
}
